diagnostic
----------

.. inheritance-diagram:: climlab.process.diagnostic
   :parts: 1
   :private-bases:

.. automodule:: climlab.process.diagnostic
    :members:
    :undoc-members:
    :show-inheritance: